@@ -5,21 +5,20 @@ use base 'HTML::FormFu::Element';
 use Class::C3;
 
 use HTML::FormFu::Attribute qw/ mk_output_accessors /;
-use HTML::FormFu::ObjectUtil qw/
-    :FORM_AND_BLOCK
-    insert_before insert_after /;
-use HTML::FormFu::Util qw/ _get_elements xml_escape /;
+use HTML::FormFu::ObjectUtil qw/ :FORM_AND_BLOCK /;
+use HTML::FormFu::Util qw/ _get_elements xml_escape process_attrs /;
 use Storable qw( dclone );
 use Carp qw/croak/;
 
-__PACKAGE__->mk_accessors(qw/ tag _elements element_defaults /);
+__PACKAGE__->mk_accessors( qw/ tag _elements element_defaults nested_name / );
 
 __PACKAGE__->mk_output_accessors(qw/ content /);
 
 __PACKAGE__->mk_inherited_accessors(
     qw/ auto_id auto_label auto_error_class auto_error_message
         auto_constraint_class auto_inflator_class auto_validator_class
-        auto_transformer_class render_processed_value force_errors /
+        auto_transformer_class render_processed_value force_errors
+        repeatable_count /
 );
 
 *elements     = \&element;
@@ -35,13 +34,24 @@ sub new {
 
     $self->_elements( [] );
     $self->element_defaults( {} );
-    $self->render_class_suffix('block');
     $self->filename('block');
     $self->tag('div');
 
     return $self;
 }
 
+sub defaults_from_model {
+    my $self = shift;
+
+    return $self->form->model->defaults_from_model(@_);
+}
+
+sub save_to_model {
+    my $self = shift;
+
+    return $self->form->model->save_to_model(@_);
+}
+
 sub process {
     my ($self) = @_;
 
@@ -50,32 +60,96 @@ sub process {
     return;
 }
 
-sub prepare_id {
-    my ( $self, $render ) = @_;
-
-    map { $_->prepare_id(@_) } @{ $self->_elements };
-
-    return;
-}
-
-sub render {
+sub render_data {
     my $self = shift;
 
-    my $render = $self->next::method( {
-            tag       => $self->tag,
-            content   => xml_escape( $self->content ),
-            _elements => [ map { $_->render } @{ $self->_elements } ],
+    my $render = $self->render_data_non_recursive( {
+            elements => [ map { $_->render_data } @{ $self->_elements } ],
             @_ ? %{ $_[0] } : () } );
 
     return $render;
 }
 
+sub render_data_non_recursive {
+    my $self = shift;
+
+    my $render = $self->next::method( {
+            tag     => $self->tag,
+            content => xml_escape( $self->content ),
+            @_ ? %{ $_[0] } : () } );
+
+    return $render;
+}
+
+sub string {
+    my ( $self, $args ) = @_;
+
+    $args ||= {};
+
+    my $render
+        = exists $args->{render_data}
+        ? $args->{render_data}
+        : $self->render_data_non_recursive;
+
+    # start_block template
+
+    my $html = '';
+
+    if ( defined $render->{tag} ) {
+        $html .= sprintf "<%s%s>",
+            $render->{tag},
+            process_attrs( $render->{attributes} );
+    }
+
+    if ( defined $render->{legend} ) {
+        $html .= sprintf "\n<legend>%s</legend>", $render->{legend};
+    }
+
+    # block template
+
+    $html .= "\n";
+
+    if ( defined $render->{content} ) {
+        $html .= sprintf "%s\n", $render->{content};
+    }
+    else {
+        for my $elem ( @{ $self->get_elements } ) {
+
+            # call render, so that child elements can use a different renderer
+            my $elem_html = $elem->render;
+
+            # skip Blank fields
+            if ( length $elem_html ) {
+                $html .= $elem_html . "\n";
+            }
+        }
+    }
+
+    # end_block template
+
+    if ( defined $render->{tag} ) {
+        $html .= sprintf "</%s>", $render->{tag};
+    }
+
+    return $html;
+}
+
 sub start {
-    return shift->render->start;
+    my ($self) = @_;
+
+    return $self->tt( {
+            filename    => 'start_block',
+            render_data => $self->render_data_non_recursive,
+        } );
 }
 
 sub end {
-    return shift->render->end;
+    my ($self) = @_;
+
+    return $self->tt( {
+            filename    => 'end_block',
+            render_data => $self->render_data_non_recursive,
+        } );
 }
 
 sub clone {
@@ -85,6 +159,8 @@ sub clone {
 
     $clone->_elements( [ map { $_->clone } @{ $self->_elements } ] );
 
+    map { $_->parent($clone) } @{ $clone->_elements };
+
     $clone->element_defaults( dclone $self->element_defaults );
 
     return $clone;
