@@ -11,8 +11,8 @@ use Carp qw/ croak /;
 sub process {
     my ( $self, $params ) = @_;
 
-    my $name  = $self->name;
-    my $value = $params->{$name};
+    my $value = $self->get_nested_hash_value( $params, $self->nested_name );
+
     my @errors;
 
     if ( ref $value eq 'ARRAY' ) {
